@@ -6,26 +6,17 @@ class Base(Checks):
         self,
         folder,
         extension=None,
-        modified_since=None,
         list_files=None,
-        expiry_download_links=7,
     ):
         super().__init__(directory=folder)
 
         self.folder = folder
         self.extension = extension
-        self.modified_since = modified_since
-        # Remove later
-        # if not self._check_azure_cli_installed():
-        #     self.method = "single"
-        # else:
-        #     self.method = method
         self.list_files = list_files
         credentials = self._check_connection_credentials()
         self.connection_string = credentials[0]
         self.account_name = credentials[1]
         self.account_key = credentials[2]
-        self.expiry_download_links = expiry_download_links
 
     def checks(self):
         if self.list_files and not isinstance(self.list_files, list):
