@@ -13,13 +13,11 @@ class Download(Base):
         source,
         folder=None,
         extension=None,
-        modified_since=None,
         list_files=None,
     ):
         super(Download, self).__init__(
             folder=folder,
             extension=extension,
-            modified_since=modified_since,
             list_files=list_files,
         )
         self.checks()
